==> converge-2.0.tar.bz2: converge-2.0/vm/Config.py <==
# Copyright (c) 2011 King's College London, created by Laurence Tratt
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.

import time


CON_VERSION = "2.0"
CON_DATE = "2012/07/31"

PLATFORM = "OpenBSD"

# Stuff needed for building the system.

def _sanitise(dirs):
    dirs = dirs.strip()
    if not dirs:
        return []
    else:
        return [x for x in dirs.split(" ") if x != ""]

LIBPCRE_INCLUDE_DIRS = _sanitise("/usr/local/include")
LIBPCRE_LIBRARY_DIRS = _sanitise("/usr/local/lib")
LIBPCRE_LIBRARIES = _sanitise("pcre ")
LIBPCRE_LINK_FLAGS = _sanitise("-Wl,-R/usr/local/lib ")
LIBPCRE_A = "/usr/local/lib/libpcre.a"

LIBXML2_INCLUDE_DIRS = _sanitise("/usr/local/include/libxml2 /usr/local/include")
LIBXML2_LIBRARY_DIRS = _sanitise("/usr/local/lib /usr/local/lib")
LIBXML2_LIBRARIES = _sanitise("xml2 z iconv m ")
LIBXML2_LINK_FLAGS = _sanitise("")
LIBXML2_A = "/usr/local/lib/libxml2.a"

==> converge-2.1.tar.bz2: converge-2.1/vm/Config.py <==
# Copyright (c) 2011 King's College London, created by Laurence Tratt
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.

import time


CON_VERSION = "2.1"
CON_DATE = "2014-02-25"

PLATFORM = "OpenBSD"

# Stuff needed for building the system.

def _sanitise(dirs):
    dirs = dirs.strip()
    if not dirs:
        return []
    else:
        return [x for x in dirs.split(" ") if x != ""]

LIBPCRE_INCLUDE_DIRS = _sanitise("/usr/local/include")
LIBPCRE_LIBRARY_DIRS = _sanitise("/usr/local/lib")
LIBPCRE_LIBRARIES = _sanitise("pcre ")
LIBPCRE_LINK_FLAGS = _sanitise("-Wl,-R/usr/local/lib ")
LIBPCRE_A = "/usr/local/lib/libpcre.a"

LIBXML2_INCLUDE_DIRS = _sanitise("/usr/local/include/libxml2 /usr/local/include")
LIBXML2_LIBRARY_DIRS = _sanitise("/usr/local/lib /usr/local/lib")
LIBXML2_LIBRARIES = _sanitise("xml2 z iconv m ")
LIBXML2_LINK_FLAGS = _sanitise("")
LIBXML2_A = "/usr/local/lib/libxml2.a"
